@@ -5,7 +5,7 @@ use warnings;
 package Hash::Ordered;
 # ABSTRACT: A fast, pure-Perl ordered hash class
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 use Carp ();
 
@@ -57,23 +57,26 @@ use overload
 #pod
 #pod Constructs an object, with an optional list of key-value pairs.
 #pod
+#pod The position of a key corresponds to the first occurrence in the list, but
+#pod the value will be updated if the key is seen more than once.
+#pod
+#pod Current API available since 0.009.
+#pod
 #pod =cut
 
 sub new {
     my $class = shift;
 
-    return bless [ {}, [], undef, 0, 0 ], $class unless @_;
-
     Carp::croak("new() requires key-value pairs") unless @_ % 2 == 0;
 
-    # must stringify keys for _KEYS array
-    my @keys;
-    for ( my $i = 0; $i < $#_; $i += 2 ) {
-        push @keys, "$_[$i]";
+    my ( %data, @keys, $k );
+    while (@_) {
+        # must stringify keys for _KEYS array
+        $k = shift;
+        push @keys, "$k" unless exists $data{$k};
+        $data{$k} = shift;
     }
-    my $self = [ {@_}, \@keys, undef, 0, 0 ];
-
-    return bless $self, $class;
+    return bless [ \%data, \@keys, undef, 0, 0 ], $class;
 }
 
 #pod =method clone
@@ -654,7 +657,7 @@ Hash::Ordered - A fast, pure-Perl ordered hash class
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -715,6 +718,11 @@ L<Hash::Ordered::Benchmarks>.
 
 Constructs an object, with an optional list of key-value pairs.
 
+The position of a key corresponds to the first occurrence in the list, but
+the value will be updated if the key is seen more than once.
+
+Current API available since 0.009.
+
 =head2 clone
 
     $oh2 = $oh->clone;
